namespace Eco.Mods.TechTree
{
    // [DoNotLocalize]
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using Eco.Gameplay.Blocks;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Economy;
    using Eco.Gameplay.Housing;
    using Eco.Gameplay.Interactions;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Minimap;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Property;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Gameplay.Pipes.LiquidComponents;
    using Eco.Gameplay.Pipes.Gases;
    using Eco.Gameplay.Systems.Tooltip;
    using Eco.Shared;
    using Eco.Shared.Math;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Shared.Items;
    using Eco.Gameplay.Pipes;
    using Eco.World.Blocks;
    
    [Serialized]
    [RequireComponent(typeof(PropertyAuthComponent))]
    [RequireComponent(typeof(MinimapComponent))]                
    [RequireComponent(typeof(HousingComponent))]                  
    [RequireComponent(typeof(SolidGroundComponent))]            
    public partial class BathtubObject : 
        WorldObject,    
        IRepresentsItem
    {
        public override LocString DisplayName { get { return Localizer.DoStr("Modern Bathtub"); } } 

        public virtual Type RepresentedItemType { get { return typeof(BathtubItem); } } 



        protected override void Initialize()
        {

            this.GetComponent<MinimapComponent>().Initialize(Localizer.DoStr("Housing"));                
            this.GetComponent<HousingComponent>().Set(BathtubItem.HousingVal);            

        }
        
        static BathtubObject()
        {
            List<BlockOccupancy> occupancyList = new List<BlockOccupancy>();
            occupancyList.Add(new BlockOccupancy(new Vector3i(-1, 0, 0), typeof (WorldObjectBlock)));
            occupancyList.Add(new BlockOccupancy(new Vector3i(1, 0, 0), typeof (WorldObjectBlock)));
            occupancyList.Add(new BlockOccupancy(new Vector3i(0, 0, 0), typeof (WorldObjectBlock)));
            WorldObject.AddOccupancy<BathtubObject>(occupancyList);
        }

        public override void Destroy()
        {
            base.Destroy();
        }
       
    }

    [Serialized]
    public partial class BathtubItem :
        WorldObjectItem<BathtubObject> 
    {
        public override LocString DisplayName { get { return Localizer.DoStr("Modern Bathtub"); } } 
        public override LocString DisplayDescription  { get { return Localizer.DoStr("Sometimes it can be nice to have clean body."); } }

        static BathtubItem()
        {
            
        }

        [TooltipChildren] public HousingValue HousingTooltip { get { return HousingVal; } }
        [TooltipChildren] public static HousingValue HousingVal { get { return new HousingValue() 
                                                {
                                                    Category = "Bathroom",
                                                    Val = 2,                                   
                                                    TypeForRoomLimit = "Washing", 
                                                    DiminishingReturnPercent = 0.5f    
        };}}
        
    }

    [RequiresSkill(typeof(GlassworkingSkill), 3)]      
    public partial class BathtubRecipe : Recipe
    {
        public BathtubRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<BathtubItem>(),
            };

            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<ConcreteItem>(typeof(GlassworkingSkill), 40, GlassworkingSkill.MultiplicativeStrategy, typeof(GlassworkingLavishResourcesTalent)),
                new CraftingElement<PlasticItem>(typeof(GlassworkingSkill), 20, GlassworkingSkill.MultiplicativeStrategy, typeof(GlassworkingLavishResourcesTalent)),      
                new CraftingElement<IronPlateItem>(typeof(GlassworkingSkill), 20, GlassworkingSkill.MultiplicativeStrategy, typeof(GlassworkingLavishResourcesTalent)),          
            };
            this.ExperienceOnCraft = 2;  
            this.CraftMinutes = CreateCraftTimeValue(typeof(BathtubRecipe), Item.Get<BathtubItem>().UILink(), 5, typeof(GlassworkingSkill), typeof(GlassworkingLavishResourcesTalent), typeof(GlassworkingParallelSpeedTalent));    
            this.Initialize(Localizer.DoStr("Modern Bathtub"), typeof(BathtubRecipe));
            CraftingComponent.AddRecipe(typeof(KilnObject), this);
        }
    }
}